==> monthofswords-common-1.21.1-38-sources.jar: com/samsthenerd/monthofswords/SwordsMod.java <==
package com.samsthenerd.monthofswords;

import com.google.common.base.Suppliers;
import com.samsthenerd.monthofswords.lucky.LuckyFunctions;
import com.samsthenerd.monthofswords.registry.*;
import dev.architectury.event.EventResult;
import dev.architectury.event.events.common.EntityEvent;
import dev.architectury.registry.registries.RegistrarManager;
import org.jetbrains.annotations.Nullable;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.function.Supplier;
import net.minecraft.class_1282;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1928;
import net.minecraft.class_1928.class_4310;
import net.minecraft.class_1928.class_4313;
import net.minecraft.class_1928.class_5198;
import net.minecraft.class_2338;
import net.minecraft.class_2960;
import net.minecraft.class_8103;

public final class SwordsMod {
    public static final String MOD_ID = "monthofswords";

    public static class_2960 id(String path){
        return class_2960.method_60655(MOD_ID, path);
    }

    public static final Supplier<RegistrarManager> MANAGER = Suppliers.memoize(() -> RegistrarManager.get(MOD_ID));

    public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    public static void init() {
        SwordsModItems.register();
        SwordsModEntities.register();
        SwordsModNetworking.commonInit();
        SwordsModLoot.init();
        SwordsModStatusEffects.init();
        SwordsModComponents.register();
        SwordsModDataLoaders.init();
        LuckyFunctions.register();

        EntityEvent.LIVING_HURT.register((class_1309 entity, class_1282 source, float amount) -> {
            class_1799 victimStack = entity.method_6047();
            if(entity instanceof class_1657 player
                && player.method_6115()
                && victimStack.method_7909().equals(SwordsModItems.DUELING_SWORD.get())
                && !source.method_48789(class_8103.field_43116)
                && !player.method_7357().method_7904(victimStack.method_7909())
            ){
                player.method_7357().method_7906(victimStack.method_7909(), 15);
                victimStack.method_7970(1, entity, class_1304.field_6173);
            }
            return EventResult.pass();
        });
    }

    public static class_4313<class_4310> DESTRUCTIVE_ADVENTURE_SWORDS = class_1928.method_8359(
      "monthOfSwordsDestructiveAdventureMode", class_5198.field_24094, class_4310.method_20759(false)
    );

    public static class_4313<class_4310> SUPER_SUPER_SAFE_SWORDS = class_1928.method_8359(
      "monthOfSwordsNoDestructionEVER", class_5198.field_24094, class_4310.method_20759(false)
    );

    public static boolean canBeDestructive(class_1657 player, @Nullable class_2338 pos){
        if(player.method_37908().method_8450().method_8355(SUPER_SUPER_SAFE_SWORDS)) return false;
        if(player.method_37908().method_8450().method_8355(DESTRUCTIVE_ADVENTURE_SWORDS)) return true;
        if(pos != null && !player.method_36971(player.method_37908(), pos)) return false;
        return player.method_7294();
    }
}

==> monthofswords-common-1.30.1-sources.jar: com/samsthenerd/monthofswords/SwordsMod.java <==
package com.samsthenerd.monthofswords;

import com.google.common.base.Suppliers;
import com.samsthenerd.monthofswords.lucky.LuckyFunctions;
import com.samsthenerd.monthofswords.registry.*;
import com.samsthenerd.monthofswords.xplat.SwordsModXPlat;
import dev.architectury.event.EventResult;
import dev.architectury.event.events.common.EntityEvent;
import dev.architectury.registry.registries.RegistrarManager;
import org.jetbrains.annotations.Nullable;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.function.Supplier;
import net.minecraft.class_1282;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1928;
import net.minecraft.class_1928.class_4310;
import net.minecraft.class_1928.class_4313;
import net.minecraft.class_1928.class_5198;
import net.minecraft.class_2338;
import net.minecraft.class_2960;
import net.minecraft.class_8103;

public final class SwordsMod {
    public static final String MOD_ID = "monthofswords";

    public static class_2960 id(String path){
        return class_2960.method_60655(MOD_ID, path);
    }

    public static final Supplier<RegistrarManager> MANAGER = Suppliers.memoize(() -> RegistrarManager.get(MOD_ID));

    public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    public static SwordsModXPlat XPLAT_INSTANCE = null;

    public static void init() {
        SwordsModAttributes.init();
        SwordsModItems.register();
        SwordsModEntities.register();
        SwordsModNetworking.commonInit();
        SwordsModLoot.init();
        SwordsModStatusEffects.init();
        SwordsModComponents.register();
        SwordsModDataLoaders.init();
        LuckyFunctions.register();
        SwordsModDataAttachments.init();

        EntityEvent.LIVING_HURT.register((class_1309 entity, class_1282 source, float amount) -> {
            class_1799 victimStack = entity.method_6047();
            if(entity instanceof class_1657 player
                && player.method_6115()
                && victimStack.method_7909().equals(SwordsModItems.DUELING_SWORD.get())
                && !source.method_48789(class_8103.field_43116)
                && !player.method_7357().method_7904(victimStack.method_7909())
            ){
                player.method_7357().method_7906(victimStack.method_7909(), 15);
                victimStack.method_7970(1, entity, class_1304.field_6173);
            }
            return EventResult.pass();
        });
    }

    public static class_4313<class_4310> DESTRUCTIVE_ADVENTURE_SWORDS = class_1928.method_8359(
      "monthOfSwordsDestructiveAdventureMode", class_5198.field_24094, class_4310.method_20759(false)
    );

    public static class_4313<class_4310> SUPER_SUPER_SAFE_SWORDS = class_1928.method_8359(
      "monthOfSwordsNoDestructionEVER", class_5198.field_24094, class_4310.method_20759(false)
    );

    public static boolean canBeDestructive(class_1657 player, @Nullable class_2338 pos){
        if(player.method_37908().method_8450().method_8355(SUPER_SUPER_SAFE_SWORDS)) return false;
        if(player.method_37908().method_8450().method_8355(DESTRUCTIVE_ADVENTURE_SWORDS)) return true;
        if(pos != null && !player.method_36971(player.method_37908(), pos)) return false;
        return player.method_7294();
    }
}
